all.Evems<-function(){
     cat("\n")
     note_for_Evess_input()
     cat("\n")
     note_for_close_window()
     EveMSpar<-data.frame(subject=c(1,2),bw=c(0),age=c(0),race=c(0),Ery=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     EveMSpar<-edit(EveMSpar)
##     EveMSpar<-ymscheck(EveMSpar)
     cat("\n\n")
     Eve.ms(length(EveMSpar$subject),EveMSpar$c,EveMSpar$tau,EveMSpar$ts,EveMSpar$D,EveMSpar$bw,EveMSpar$age,EveMSpar$race,EveMSpar$Ery)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Evess_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Evecpr(6.07,EveMSpar$D,EveMSpar$tau,EveMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mcg/L)")
     output1<-coutput
     show(coutput)
     C<-Evecpr(6.07,EveMSpar$D,EveMSpar$tau,EveMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mcg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}